@@ -18,7 +18,7 @@ use crate::{
     lit::{Bool, Number, Str},
     module::ModuleItem,
     pat::{ArrayPat, AssignPat, ObjectPat, Pat, RestPat},
-    BigInt, BindingIdent, TplElement,
+    BigInt, BindingIdent, PrivateName, TplElement,
 };
 
 #[ast_node("TsTypeAnnotation")]
@@ -101,7 +101,7 @@ pub struct TsQualifiedName {
     #[span(lo)]
     pub left: TsEntityName,
     #[span(hi)]
-    pub right: Ident,
+    pub right: TsMemberName,
 }
 
 #[ast_node]
@@ -116,6 +116,18 @@ pub enum TsEntityName {
     Ident(Ident),
 }
 
+#[ast_node]
+#[derive(Eq, Hash, Is, EqIgnoreSpan)]
+#[allow(variant_size_differences)]
+#[cfg_attr(feature = "arbitrary", derive(arbitrary::Arbitrary))]
+pub enum TsMemberName {
+    #[tag("Identifier")]
+    Ident(Ident),
+
+    #[tag("PrivateName")]
+    PrivateName(PrivateName),
+}
+
 // ================
 // TypeScript type members (for type literal / interface / class)
 // ================
